local _, ns = ...


-- here is your custom color. note: it acts as a filter applied to the texture image.
ns.R, ns.G, ns.B = 0.1, 1.0, 0.1


local f = CreateFrame('GameTooltip')
f:SetOwner(WorldFrame, 'ANCHOR_NONE')
f:SetScript('OnEvent', function (self, event, ...) return ns[event](ns, event, ...) end)
function ns:RegisterEvent (event) return f:RegisterEvent(event) end
function ns:UnregisterEvent (event) return f:UnregisterEvent(event) end

local lines = {}
for line = 1, 40 do
	lines[line] = f:CreateFontString()
	f:AddFontStrings(lines[line], f:CreateFontString())
end

local _, _, _, _, glyph, _, recipe = GetAuctionItemClasses()
local _, _, companion_pets, _, _, mount = GetAuctionItemSubClasses(9)
local knowables = { [glyph] = true, [recipe] = true, [companion_pets] = true, [mount] = true, }

local knowns = {}

local petPattern = ITEM_PET_KNOWN:gsub('%(', '%%(')
petPattern = petPattern:gsub('%)', '%%)')

local function Scan (line, numLines)
	if ( line > numLines ) then return end

	local text = lines[line]:GetText()
	if ( not text or text == '' or text ~= ITEM_SPELL_KNOWN and not text:match(petPattern) ) then return Scan(line + 1, numLines) end

	return true
end

function ns:IsKnown (link)
	if ( not link ) then return end

	local speciesID = link:match('battlepet:(%d+):')
	if ( speciesID ) then return C_PetJournal.GetNumCollectedInfo(speciesID) > 0 and true end

	local itemID = link:match('item:(%d+):')
	if ( not itemID ) then return end
	if ( knowns[itemID] ) then return true end

	local _, _, _, _, _, itemType, itemSubType = GetItemInfo(itemID)
	if ( not (knowables[itemType] or knowables[itemSubType]) ) then return end

	f:ClearLines()
	f:SetHyperlink(link)
	if ( not Scan(1, f:NumLines()) ) then return end

	if ( itemSubType ~= companion_pets ) then knowns[itemID] = true end
	return true
end

local addons = {}
ns.addons = addons

function ns:ADDON_LOADED (event, name)
	local func = addons[name]
	if ( not func ) then return end

	func()
	addons[name] = nil

	if ( not next(addons) ) then
		self:UnregisterEvent(event)
		self[event] = nil
	end
end
ns:RegisterEvent('ADDON_LOADED')
